==> jscad__x3d-serializer-2.3.3.jar: META-INF/resources/webjars/jscad__x3d-serializer/2.3.3/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.3.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.2...@jscad/x3d-serializer@2.3.3) (2022-02-19)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.1...@jscad/x3d-serializer@2.3.2) (2021-12-26)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.0...@jscad/x3d-serializer@2.3.1) (2021-12-11)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.3.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.8...@jscad/x3d-serializer@2.3.0) (2021-11-07)


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





## [2.2.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.7...@jscad/x3d-serializer@2.2.8) (2021-10-17)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.6...@jscad/x3d-serializer@2.2.7) (2021-10-04)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.5...@jscad/x3d-serializer@2.2.6) (2021-09-27)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.4...@jscad/x3d-serializer@2.2.5) (2021-09-09)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.3...@jscad/x3d-serializer@2.2.4) (2021-06-20)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.2...@jscad/x3d-serializer@2.2.3) (2021-06-11)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.1...@jscad/x3d-serializer@2.2.2) (2021-06-01)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.0...@jscad/x3d-serializer@2.2.1) (2021-04-20)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.2.0) (2021-04-17)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))
* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.1.0) (2021-04-15)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))
* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.12...@jscad/x3d-serializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.12](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.11...@jscad/x3d-serializer@2.0.0-alpha.12) (2021-03-07)


### Bug Fixes

* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.10...@jscad/x3d-serializer@2.0.0-alpha.11) (2021-02-07)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.9...@jscad/x3d-serializer@2.0.0-alpha.10) (2021-01-02)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.8...@jscad/x3d-serializer@2.0.0-alpha.9) (2020-12-04)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.7...@jscad/x3d-serializer@2.0.0-alpha.8) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.6...@jscad/x3d-serializer@2.0.0-alpha.7) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.5...@jscad/x3d-serializer@2.0.0-alpha.6) (2020-09-29)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.4...@jscad/x3d-serializer@2.0.0-alpha.5) (2020-09-28)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.3...@jscad/x3d-serializer@2.0.0-alpha.4) (2020-09-19)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.2...@jscad/x3d-serializer@2.0.0-alpha.3) (2020-09-08)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.1...@jscad/x3d-serializer@2.0.0-alpha.2) (2020-09-02)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/x3d-serializer





# 2.0.0-alpha.0 (2020-08-13)


### Features

* **x3d-serializer:** overhaul for V2 (#476)





<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.2...@jscad/x3d-serializer@0.2.0) (2018-11-25)



<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.1...@jscad/x3d-serializer@0.1.2) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.0...@jscad/x3d-serializer@0.1.1) (2017-12-14)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.6...@jscad/x3d-serializer@0.1.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.0.6"></a>
## [0.0.6](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.5...@jscad/x3d-serializer@0.0.6) (2017-11-04)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.5"></a>
## [0.0.5](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.4...@jscad/x3d-serializer@0.0.5) (2017-10-30)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.3...@jscad/x3d-serializer@0.0.4) (2017-10-10)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.3"></a>
## 0.0.3 (2017-10-10)




**Note:** Version bump only for package @jscad/x3d-serializer

==> jscad__x3d-serializer-2.4.3.jar: META-INF/resources/webjars/jscad__x3d-serializer/2.4.3/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.4.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.4.2...@jscad/x3d-serializer@2.4.3) (2022-11-26)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.4.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.4.1...@jscad/x3d-serializer@2.4.2) (2022-08-21)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.4.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.4.0...@jscad/x3d-serializer@2.4.1) (2022-07-17)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.4.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.9...@jscad/x3d-serializer@2.4.0) (2022-06-12)


### Features

* **x3d-serializer:** enhanced to convert 2D geometry and path to X3D Polyline2D ([#1091](https://github.com/jscad/OpenJSCAD.org/issues/1091)) ([4f763a8](https://github.com/jscad/OpenJSCAD.org/commit/4f763a8def39f3b0454f2079f3c1fd7da52dd880))





## [2.3.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.8...@jscad/x3d-serializer@2.3.9) (2022-05-15)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.7...@jscad/x3d-serializer@2.3.8) (2022-04-24)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.6...@jscad/x3d-serializer@2.3.7) (2022-04-03)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.5...@jscad/x3d-serializer@2.3.6) (2022-04-03)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.4...@jscad/x3d-serializer@2.3.5) (2022-03-13)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.3...@jscad/x3d-serializer@2.3.4) (2022-03-06)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.2...@jscad/x3d-serializer@2.3.3) (2022-02-19)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.1...@jscad/x3d-serializer@2.3.2) (2021-12-26)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.3.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.3.0...@jscad/x3d-serializer@2.3.1) (2021-12-11)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.3.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.8...@jscad/x3d-serializer@2.3.0) (2021-11-07)


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





## [2.2.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.7...@jscad/x3d-serializer@2.2.8) (2021-10-17)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.6...@jscad/x3d-serializer@2.2.7) (2021-10-04)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.5...@jscad/x3d-serializer@2.2.6) (2021-09-27)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.4...@jscad/x3d-serializer@2.2.5) (2021-09-09)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.3...@jscad/x3d-serializer@2.2.4) (2021-06-20)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.2...@jscad/x3d-serializer@2.2.3) (2021-06-11)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.1...@jscad/x3d-serializer@2.2.2) (2021-06-01)

**Note:** Version bump only for package @jscad/x3d-serializer





## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.2.0...@jscad/x3d-serializer@2.2.1) (2021-04-20)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.2.0) (2021-04-17)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))
* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.1.0) (2021-04-15)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))
* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))
* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.12...@jscad/x3d-serializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.12](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.11...@jscad/x3d-serializer@2.0.0-alpha.12) (2021-03-07)


### Bug Fixes

* **modeling:** V2 revisit modifiers ([#773](https://github.com/jscad/OpenJSCAD.org/issues/773)) ([1e28120](https://github.com/jscad/OpenJSCAD.org/commit/1e28120d2b8505dc1882cf3d607296d6fcd5526d))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.10...@jscad/x3d-serializer@2.0.0-alpha.11) (2021-02-07)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.9...@jscad/x3d-serializer@2.0.0-alpha.10) (2021-01-02)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.8...@jscad/x3d-serializer@2.0.0-alpha.9) (2020-12-04)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.7...@jscad/x3d-serializer@2.0.0-alpha.8) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.6...@jscad/x3d-serializer@2.0.0-alpha.7) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.5...@jscad/x3d-serializer@2.0.0-alpha.6) (2020-09-29)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.4...@jscad/x3d-serializer@2.0.0-alpha.5) (2020-09-28)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.3...@jscad/x3d-serializer@2.0.0-alpha.4) (2020-09-19)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.2...@jscad/x3d-serializer@2.0.0-alpha.3) (2020-09-08)

**Note:** Version bump only for package @jscad/x3d-serializer





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.1...@jscad/x3d-serializer@2.0.0-alpha.2) (2020-09-02)


### Bug Fixes

* **all:** update dependencies ([d8c713a](https://github.com/jscad/OpenJSCAD.org/commit/d8c713a933b97a6d179ed3d3e923e188e334f99e))





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/x3d-serializer@2.0.0-alpha.0...@jscad/x3d-serializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/x3d-serializer





# 2.0.0-alpha.0 (2020-08-13)


### Features

* **x3d-serializer:** overhaul for V2 (#476)





<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.2...@jscad/x3d-serializer@0.2.0) (2018-11-25)



<a name="0.1.2"></a>
## [0.1.2](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.1...@jscad/x3d-serializer@0.1.2) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.1.1"></a>
## [0.1.1](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.1.0...@jscad/x3d-serializer@0.1.1) (2017-12-14)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.6...@jscad/x3d-serializer@0.1.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.0.6"></a>
## [0.0.6](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.5...@jscad/x3d-serializer@0.0.6) (2017-11-04)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.5"></a>
## [0.0.5](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.4...@jscad/x3d-serializer@0.0.5) (2017-10-30)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/x3d-serializer@0.0.3...@jscad/x3d-serializer@0.0.4) (2017-10-10)




**Note:** Version bump only for package @jscad/x3d-serializer

<a name="0.0.3"></a>
## 0.0.3 (2017-10-10)




**Note:** Version bump only for package @jscad/x3d-serializer
